aa_models/alert/alert_action library

Classes

AAAlertAction
An action that can be performed from an AAAlertTemplate on Android Auto.

Enums

AAAlertActionStyle
Display styles for an alert action button on Android Auto.