AAGridButton class
A single cell in an AAGridTemplate.
Each button shows a titleVariants label and an optional image. The first element of titleVariants is used as the primary title on Android Auto (Car App Library shows the most appropriate variant according to available space).
Constructors
-
AAGridButton({required List<
String> titleVariants, String? image, String? loadingMessage, Future<void> onPress(dynamic complete(), AAGridButton self)?})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- image → String?
-
Image displayed inside the grid cell. Supports three formats:
final
- loadingMessage → String?
-
Text displayed as the loading screen title while onPress is executing
(until
completeis called). When null, no title is shown.final -
onPress
→ Future<
void> Function(dynamic complete(), AAGridButton self)? -
Callback fired when the user taps this button.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
titleVariants
→ List<
String> -
Label variants displayed beneath the cell image. Must not be empty.
final
- uniqueId → String
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited