onPress property

Future<void> Function(dynamic complete(), AAGridButton self)? onPress
final

Callback fired when the user taps this button.

  • complete must be called after processing to dismiss the loading screen and rebuild the template — identical to AAListItem behaviour.
  • self is a reference to the tapped button itself.

Implementation

final Future<void> Function(Function() complete, AAGridButton self)? onPress;