emptyViewTitleVariants property
Messages displayed when buttons is empty.
Android Auto uses the first element as the text passed to
ItemList.Builder.setNoItemsMessage(). When buttons is empty and
this list is null or empty, the template shows a loading indicator.
Implementation
final List<String>? emptyViewTitleVariants;