tabTitle property

String? tabTitle
final

Label displayed on the tab bar item when this template is used as a tab inside an AATabBarTemplate. Falls back to title when not set.

Implementation

final String? tabTitle;