AAToggle class
Constructors
- AAToggle({bool isChecked = false, bool? isEnabled, dynamic onCheckedChange(bool checked, AAListItem self)?})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isChecked ↔ bool
-
getter/setter pair
- isEnabled → bool?
-
final
- onCheckedChange → dynamic Function(bool checked, AAListItem self)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited