svgRasterSize property
The size used when rasterizing Flutter asset SVGs referenced by image fields before they are sent to the native side.
Implementation
static int svgRasterSize = defaultSvgRasterSize;
The size used when rasterizing Flutter asset SVGs referenced by image fields before they are sent to the native side.
static int svgRasterSize = defaultSvgRasterSize;