resumeConnection method
void
resumeConnection()
A function that will resume the paused all event listeners from CarPlay.
Implementation
void resumeConnection() {
_eventBroadcast?.resume();
}
A function that will resume the paused all event listeners from CarPlay.
void resumeConnection() {
_eventBroadcast?.resume();
}