controllers/all library

Classes

FlutterAndroidAutoController
FlutterAndroidAutoController is an root object in order to control and communication system with the Android Auto and native functions.
FlutterCarPlayController
FlutterCarPlayController is an root object in order to control and communication system with the Apple CarPlay and native functions.