FlutterAndroidAutoController class

FlutterAndroidAutoController is a root object used to control and communicate with Android Auto native functions.

Properties

eventChannel EventChannel
no setter
hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

flutterToNativeModule(FAAChannelTypes type, [dynamic data]) Future<bool?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
processFAAAlertActionPressed(String elementId) → void
processFAAGridButtonPressed(String elementId) Future<void>
processFAAListItemSelectedChannel(String elementId) Future<void>
processFAAListSectionSelectedChannel(String elementId, int selectedIndex) → void
processFAAPaneActionPressedChannel(String elementId) → void
processFAAPresentStateChanged(String elementId, bool completed) → void
processFAAToggleCheckedChangeChannel(String elementId, bool checked) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

currentPresentTemplate AATemplate?
The currently presented modal, i.e. AAAlertTemplate.
getter/setter pair
currentRootTemplate AATemplate?
no setter
templateHistory List<AATemplate>
AATabBarTemplate, AAGridTemplate, AAListTemplate, AAPaneTemplate, AAMessageTemplate, and AALongMessageTemplate in a list.
getter/setter pair

Static Methods

flutterToNativeModuleStatic(FAAChannelTypes type, [dynamic data]) Future<bool?>
updateAAListTemplateSections({required String elementId, required List<AAListSection> sections}) Future<void>