flutter_carplay library

Classes

AAListItem
AAListSection
AAListTemplate
AATemplate
CPActionSheetTemplate
A template that displays a modal action sheet. https://developer.apple.com/documentation/carplay/cpactionsheettemplate iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 13.1+
CPActionsTemplate
CPAlertAction
An object that encapsulates an action the user can perform on an action sheet or alert. https://developer.apple.com/documentation/carplay/cpalertaction iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 13.1+
CPAlertTemplate
A template that displays a modal alert. https://developer.apple.com/documentation/carplay/cpalerttemplate iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 13.1+
CPBarButton
A button for placement in a navigation bar. https://developer.apple.com/documentation/carplay/cpbarbutton iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 13.1+
CPGridButton
A menu item button displayed on a grid template. https://developer.apple.com/documentation/carplay/cpgridbutton iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 13.1+
CPGridTemplate
Creates a grid template with a title and a set of buttons. https://developer.apple.com/documentation/carplay/cpgridtemplate iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 13.1+
CPInformationItem
A data object that provides content for an information template. https://developer.apple.com/documentation/carplay/cpinformationitem iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
CPInformationTemplate
A template object that displays and manages information items and text buttons. https://developer.apple.com/documentation/carplay/cpinformationtemplate iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
CPListImageRowItem
A List template row that displays a series of images. https://developer.apple.com/documentation/carplay/cplistimagerowitem iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
CPListImageRowItemCardElement
https://developer.apple.com/documentation/carplay/cplistimagerowitemcardelement iOS 26.0+ | iPadOS 26.0+ | Mac Catalyst 26.0+
CPListImageRowItemCondensedElement
https://developer.apple.com/documentation/carplay/cplistimagerowitemcondensedelement iOS 26.0+ | iPadOS 26.0+ | Mac Catalyst 26.0+
CPListImageRowItemElement
Abstract superclass for a a row item element object. iOS 26.0+ | iPadOS 26.0+ | Mac Catalyst 26.0+ https://developer.apple.com/documentation/carplay/cplistimagerowitemelement
CPListImageRowItemGridElement
https://developer.apple.com/documentation/carplay/cplistimagerowitemgridelement iOS 26.0+ | iPadOS 26.0+ | Mac Catalyst 26.0+
CPListImageRowItemImageGridElement
https://developer.apple.com/documentation/carplay/cplistimagerowitemimagegridelement iOS 26.0+ | iPadOS 26.0+ | Mac Catalyst 26.0+
CPListImageRowItemRowElement
https://developer.apple.com/documentation/carplay/cplistimagerowitemrowelement iOS 26.0+ | iPadOS 26.0+ | Mac Catalyst 26.0+
CPListItem
A selectable row in a list template. https://developer.apple.com/documentation/carplay/cplistitem iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 13.1+
CPListSection
A container that groups your list items into sections. https://developer.apple.com/documentation/carplay/cplistsection iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 13.1+
CPListTemplate
A template that displays and manages a list of items. https://developer.apple.com/documentation/carplay/CPListTemplate iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 13.1+
CPListTemplateItem
A description of the common properties of all list item types. https://developer.apple.com/documentation/carplay/cplisttemplateitem iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
CPPointOfInterest
A section object of list items that appear in a list template. https://developer.apple.com/documentation/carplay/cppointofinterest iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
CPPointOfInterestTemplate
A template that displays a map with selectable points of interest. https://developer.apple.com/documentation/carplay/cppointofinteresttemplate iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
CPTabBarTemplate
A container template that displays and manages other templates, presenting them as tabs. Supported template types: CPListTemplate, CPPointOfInterestTemplate, CPGridTemplate, CPInformationTemplate, CPActionSheetTemplate, CPAlertTemplate https://developer.apple.com/documentation/carplay/cptabbartemplate iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
CPTemplate
https://developer.apple.com/documentation/carplay/cptemplate iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 13.1+
CPTextButton
A button that displays a stylized title. https://developer.apple.com/documentation/carplay/CPTextButton iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 13.1+
EnumUtils
FlutterAndroidAuto
An object in order to integrate Android auto in navigation and manage all user interface elements appearing on your screens displayed on the Android Auto screen.
FlutterAutoAndroidHelper
FlutterCarplay
An object in order to integrate Apple CarPlay in navigation and manage all user interface elements appearing on your screens displayed on the CarPlay screen.
FlutterCarplayHelper
UIColor
An object that stores color data and sometimes opacity. iOS 2.0+ | iPadOS 2.0+ | Mac Catalyst 13.1+

Enums

ConnectionStatusTypes
CPAlertActionStyle
Display styles for an alert’s action button. iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 13.1+
CPBarButtonStyle
The display style of a bar button. iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
CPInformationTemplateLayout
The layout that an information template uses to arrange its items. iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
CPListImageRowItemCondensedElementShape
Types of shape used to draw a condensed row element. iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 14.0+
CPListImageRowItemImageGridElementShape
Types of shape used to draw a condensed row element. iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 14.0+
CPListItemAccessoryType
The accessory types that a list item can display. iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
CPListItemPlayingIndicatorLocation
The locations where a list item can display the Now Playing indicator. iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
CPTextButtonStyle
FAAChannelTypes
FCPChannelTypes