FlutterAutoAndroidHelper class

Constructors

FlutterAutoAndroidHelper()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

findAAGridButton({required List<AATemplate> templates, required String elementId}) → AAGridButton?
findAAListItem({required List<AATemplate> templates, required String elementId}) → AAListItem?
findAAListSection({required List<AATemplate> templates, required String elementId}) → AAListSection?
findAAPaneAction({required List<AATemplate> templates, required String elementId}) → AAPaneAction?
makeFAAChannelId({String event = ''}) → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited