clearSvgRasterCache function
Clears the in-memory rasterized SVG cache.
Primarily intended for tests, but safe to call at any time.
Implementation
@visibleForTesting
void clearSvgRasterCache() => _svgRasterCache.clear();
Clears the in-memory rasterized SVG cache.
Primarily intended for tests, but safe to call at any time.
@visibleForTesting
void clearSvgRasterCache() => _svgRasterCache.clear();