CPActionSheetTemplate class

A template that displays a modal action sheet. https://developer.apple.com/documentation/carplay/cpactionsheettemplate iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 13.1+

Inheritance
Implemented types

Constructors

CPActionSheetTemplate({String? title, String? message, required List<CPAlertAction> actions, String? tabTitle, bool showsTabBadge = false, String? systemIcon, String? id})
Creates CPActionSheetTemplate

Properties

actions List<CPAlertAction>
The list of actions available on the action sheet. iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 13.1+
final
hashCode int
The hash code for this object.
no setterinherited
message String?
The descriptive message providing details about the reason for displaying the action sheet. iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 13.1+
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showsTabBadge bool
An indicator you use to call attention to the tab. iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
finalinherited
systemIcon String?
An image that represents the content of the tab. Note:
finalinherited
tabTitle String?
A short title that describes the content of the tab. iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
finalinherited
title String?
The title of the action sheet. iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 13.1+
final
uniqueId String
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited