CPBarButton class

A button for placement in a navigation bar. https://developer.apple.com/documentation/carplay/cpbarbutton iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 13.1+

Constructors

CPBarButton({required String title, CPBarButtonStyle buttonStyle = CPBarButtonStyle.rounded, required dynamic onPress(), String? id})
Creates CPBarButton

Properties

buttonStyle CPBarButtonStyle
The style to use when displaying the button. Default is CPBarButtonStyle.rounded iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
final
hashCode int
The hash code for this object.
no setterinherited
onPress → dynamic Function()
A block that CarPlay calls when the user taps a bar button. iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
The title displayed on the bar button. iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 13.1+
final
uniqueId String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited