onPress property
dynamic Function()
onPress
final
A block that CarPlay calls when the user taps a bar button. iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
Implementation
final Function() onPress;
A block that CarPlay calls when the user taps a bar button. iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
final Function() onPress;