CPTextButton class

A button that displays a stylized title. https://developer.apple.com/documentation/carplay/CPTextButton iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 13.1+

Constructors

CPTextButton({required String title, CPTextButtonStyle textstyle = CPTextButtonStyle.normal, required dynamic onPress(), String? id})
Creates CPTextButton

Properties

hashCode int
The hash code for this object.
no setterinherited
onPress → dynamic Function()
A closure that CarPlay invokes when the user taps the button. iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textstyle CPTextButtonStyle
The text style the button applies to its title. Default is CPTextButtonStyle.normal iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
final
title String
The text the button displays. iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
final
uniqueId String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited