textstyle property
The text style the button applies to its title. Default is CPTextButtonStyle.normal iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
Implementation
final CPTextButtonStyle textstyle;
The text style the button applies to its title. Default is CPTextButtonStyle.normal iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
final CPTextButtonStyle textstyle;