selectedSafe property
Adds contrast protection where the platform does not manage selected-state icon contrast for us. Currently this is applied by the CarPlay renderer.
Implementation
final bool selectedSafe;
Adds contrast protection where the platform does not manage selected-state icon contrast for us. Currently this is applied by the CarPlay renderer.
final bool selectedSafe;