onPress property
dynamic Function()?
onPress
final
The block invoked after the user taps the button. iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 13.1+
Implementation
final Function()? onPress;
The block invoked after the user taps the button. iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 13.1+
final Function()? onPress;