CPGridTemplate class

Creates a grid template with a title and a set of buttons. https://developer.apple.com/documentation/carplay/cpgridtemplate iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 13.1+

Inheritance

Constructors

CPGridTemplate({required String title, required List<CPGridButton> buttons, String? tabTitle, bool showsTabBadge = false, String? systemIcon, String? id})
Creates CPGridTemplate in order to display a grid of items as buttons. When creating the grid template, provide an array of CPGridButton objects. Each button must contain a title that is shown in the grid template's navigation bar.

Properties

buttons List<CPGridButton>
The array of grid buttons displayed on the template. iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 13.1+
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showsTabBadge bool
An indicator you use to call attention to the tab. iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
finalinherited
systemIcon String?
An image that represents the content of the tab. Note:
finalinherited
tabTitle String?
A short title that describes the content of the tab. iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
finalinherited
title String
The title shown in the grid template’s navigation bar. systemIcon must be set in order for the title to be displayed in a tab bar. iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 13.1+
final
uniqueId String
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited