CPGridTemplate constructor

CPGridTemplate({
  1. required String title,
  2. required List<CPGridButton> buttons,
  3. String? tabTitle,
  4. bool showsTabBadge = false,
  5. String? systemIcon,
  6. String? id,
})

Creates CPGridTemplate in order to display a grid of items as buttons. When creating the grid template, provide an array of CPGridButton objects. Each button must contain a title that is shown in the grid template's navigation bar.

Implementation

CPGridTemplate({
  required this.title,
  required this.buttons,
  super.tabTitle,
  super.showsTabBadge = false,
  super.systemIcon,
  String? id,
}) : _elementId = id ?? const Uuid().v4();