buttons property
The array of grid buttons displayed on the template. iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 13.1+
Implementation
final List<CPGridButton> buttons;
The array of grid buttons displayed on the template. iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 13.1+
final List<CPGridButton> buttons;