title property
The title shown in the grid template’s navigation bar. systemIcon must be set in order for the title to be displayed in a tab bar. iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 13.1+
Implementation
final String title;
The title shown in the grid template’s navigation bar. systemIcon must be set in order for the title to be displayed in a tab bar. iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 13.1+
final String title;