layout property
The layout that the template uses to arrange its items. iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
Implementation
final CPInformationTemplateLayout layout;
The layout that the template uses to arrange its items. iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
final CPInformationTemplateLayout layout;