CPListImageRowItem class

A List template row that displays a series of images. https://developer.apple.com/documentation/carplay/cplistimagerowitem iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+

Inheritance

Constructors

CPListImageRowItem({String? text, List<String>? gridImages, List<String>? imageTitles, List<CPListImageRowItemElement>? elements, bool allowsMultipleLines = false, dynamic onPress(dynamic complete(), CPListImageRowItem self)?, dynamic onItemPress(dynamic complete(), CPListImageRowItem self, int? index)?, String? id})
Creates CPListImageRowItem

Properties

allowsMultipleLines bool
A Boolean value indicating whether the elements should be visible in more than a single line. iOS 26.0+ | iPadOS 26.0+ | Mac Catalyst 26.0+
final
elements List<CPListImageRowItemElement>?
The array of elements used to draw visible elements. Can be one of the following types of elements:
getter/setter pair
gridImages List<String>?
The images that appear in the list item’s image row. iOS 14.0–26.0 | iPadOS 14.0–26.0 | Mac Catalyst 14.0–26.0
final
hashCode int
The hash code for this object.
no setterinherited
imageTitles List<String>?
The titles displayed for each image in this image row item. iOS 14.0–26.0 | iPadOS 14.0–26.0 | Mac Catalyst 14.0–26.0'
final
onItemPress ↔ dynamic Function(dynamic complete(), CPListImageRowItem self, int? index)?
An optional closure that CarPlay invokes when the user selects an image. iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
getter/setter pair
onPress ↔ dynamic Function(dynamic complete(), CPListImageRowItem self)?
An optional closure that CarPlay invokes when the user selects the list item. iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String?
The item’s primary text. iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
getter/setter pairinherited
uniqueId String
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setElements(List<CPListImageRowItemElement> elements) → void
setText(String text) → void
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getMaximumNumberOfGridImages() Future<int?>
The maximum number of images that an image row can contain. iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 14.0+