elements property

List<CPListImageRowItemElement>? elements
getter/setter pair

The array of elements used to draw visible elements. Can be one of the following types of elements:

Implementation

List<CPListImageRowItemElement>? elements;