models/list/list_image_row_item/all library

Enums

CPListImageRowItemCondensedElementShape
Types of shape used to draw a condensed row element. iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 14.0+
CPListImageRowItemImageGridElementShape
Types of shape used to draw a condensed row element. iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 14.0+