setAccessoryImage method

void setAccessoryImage(
  1. String? accessoryImage
)

Updating the image displayed in the trailing region of the list item cell.

Supports the same asset path, file path, and network URL formats as image.

Implementation

void setAccessoryImage(String? accessoryImage) {
  this.accessoryImage = accessoryImage;
  FlutterCarPlayController.updateCPListItem(this);
}