CPListTemplate class

A template that displays and manages a list of items. https://developer.apple.com/documentation/carplay/CPListTemplate iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 13.1+

Inheritance

Constructors

CPListTemplate({String? title, required List<CPListSection> sections, List<String>? emptyViewTitleVariants, List<String>? emptyViewSubtitleVariants, String? tabTitle, bool showsTabBadge = false, String? systemIcon, VoidCallback? onPop, CPBarButton? backButton, String? id})
Creates CPListTemplate to display a list of items, grouped into one or more sections. Each section contains an array of list items — objects that is CPListItem

Properties

backButton → CPBarButton?
A button to display as the Back button on the navigation bar. iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 13.1+
final
emptyViewSubtitleVariants → List<String>?
An array of subtitle variants for the template’s empty view. iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
final
emptyViewTitleVariants → List<String>?
An array of title variants for the template’s empty view. iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
final
hashCode → int
The hash code for this object.
no setterinherited
onPop → VoidCallback?
Called when this template is popped from the navigation stack.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sections → List<CPListSection>
The sections that the list displays. iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 13.1+
final
showsTabBadge → bool
An indicator you use to call attention to the tab. iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
finalinherited
systemIcon → String?
An image that represents the content of the tab. Note:
finalinherited
tabTitle → String?
A short title that describes the content of the tab. iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
finalinherited
title → String?
The title that the navigation bar displays when the template is visible Notes:
final
uniqueId → String
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited
updateSections(List<CPListSection> newSections) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getMaximumItemCount() → Future<int?>
The maximum number of items, across all sections, that the template can display. iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
getMaximumSectionCount() → Future<int?>
The maximum number of sections that the template can display. iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+