backButton property
A button to display as the Back button on the navigation bar. iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 13.1+
Implementation
final CPBarButton? backButton;
A button to display as the Back button on the navigation bar. iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 13.1+
final CPBarButton? backButton;