models/poi/all library

Classes

CPPointOfInterest
A section object of list items that appear in a list template. https://developer.apple.com/documentation/carplay/cppointofinterest iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
CPPointOfInterestTemplate
A template that displays a map with selectable points of interest. https://developer.apple.com/documentation/carplay/cppointofinteresttemplate iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+