CPPointOfInterest class

A section object of list items that appear in a list template. https://developer.apple.com/documentation/carplay/cppointofinterest iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+

Constructors

CPPointOfInterest({required double latitude, required double longitude, required String title, String? subtitle, String? summary, String? detailTitle, String? detailSubtitle, String? detailSummary, String? image, CPTextButton? primaryButton, CPTextButton? secondaryButton, String? id})
Creates CPPointOfInterest

Properties

detailSubtitle String?
The detail card’s subtitle. iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
getter/setter pair
detailSummary String?
A brief summary that the detail card displays. iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
getter/setter pair
detailTitle String?
The detail card’s title. iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
image String?
A custom image that the map annotation displays. Supports three formats:
getter/setter pair
latitude double
The latitude of the geographical coordinate. iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
getter/setter pair
longitude double
The longitude of the geographical coordinate. iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
getter/setter pair
primaryButton CPTextButton?
The detail card’s primary action button. iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondaryButton CPTextButton?
The detail card’s secondary action button. iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
getter/setter pair
subtitle String?
The subtitle that the picker displays for the item. iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
getter/setter pair
summary String?
A brief summary that the picker displays for the item. iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
getter/setter pair
title String
The title that the picker displays for the item. iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
getter/setter pair
uniqueId String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited