models/search/all library
Classes
- CPSearchTemplate
- A template that provides the ability to search for a destination and see a list of search results. https://developer.apple.com/documentation/carplay/cpsearchtemplate iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 13.1+