CPSearchTemplate class
A template that provides the ability to search for a destination and see a list of search results. https://developer.apple.com/documentation/carplay/cpsearchtemplate iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 13.1+
- Inheritance
-
- Object
- CPTemplate
- CPSearchTemplate
Constructors
-
CPSearchTemplate({String? id, dynamic onUpdatedSearchText(String searchText, dynamic update(List<
CPListItem> results))?, dynamic onSelectedResult(CPListItem selectedItem, dynamic complete())?, dynamic onSearchTemplateSearchButtonPressed()?}) - Creates CPSearchTemplate to display a CarPlay search interface.
Properties
-
currentResults
→ List<
CPListItem> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- onPop → VoidCallback?
-
Called when this template is popped from the navigation stack.
finalinherited
- onSearchTemplateSearchButtonPressed → dynamic Function()?
-
Tells the delegate that the user tapped the keyboard's search button.
iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 13.1+
final
- onSelectedResult → dynamic Function(CPListItem selectedItem, dynamic complete())?
-
Tells the delegate that the user selected an item from the search result.
iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 13.1+
final
-
onUpdatedSearchText
→ dynamic Function(String searchText, dynamic update(List<
CPListItem> results))? -
Tells the delegate that the user updated the search criteria text.
iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 13.1+
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showsTabBadge → bool
-
An indicator you use to call attention to the tab.
iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
finalinherited
- systemIcon → String?
-
An image that represents the content of the tab.
Note:
finalinherited
- tabTitle → String?
-
A short title that describes the content of the tab.
iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
finalinherited
- uniqueId → String
-
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
updateResults(
List< CPListItem> results) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited