CPTabBarTemplate class

A container template that displays and manages other templates, presenting them as tabs. Supported template types: CPListTemplate, CPPointOfInterestTemplate, CPGridTemplate, CPInformationTemplate, CPActionSheetTemplate, CPAlertTemplate https://developer.apple.com/documentation/carplay/cptabbartemplate iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+

Inheritance

Constructors

CPTabBarTemplate({required List<CPTemplate> templates, String? tabTitle, bool showsTabBadge = false, String? systemIcon, String? id})
When creating a CPTabBarTemplate, provide an array of templates for the tab bar to display. CarPlay treats the array’s templates as root templates, each with its own navigation hierarchy. When a tab bar template is the rootTemplate of your app’s interface controller and you use the controller to add and remove templates, CarPlay applies those changes to the selected tab’s navigation hierarchy.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showsTabBadge bool
An indicator you use to call attention to the tab. iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
finalinherited
systemIcon String?
An image that represents the content of the tab. Note:
finalinherited
tabTitle String?
A short title that describes the content of the tab. iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
finalinherited
templates List<CPTemplate>
The tab bar’s templates. Supported types: CPListTemplate, CPPointOfInterestTemplate, CPGridTemplate, CPInformationTemplate iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
final
uniqueId String
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited
updateTemplates(List<CPTemplate> newTemplates) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited