AAListSection class

Constructors

AAListSection({String? title, required List<AAListItem> items, int? selectedIndex, dynamic onSelected(int selectedIndex, AAListItem selectedItem)?, String? id})

Properties

hashCode int
The hash code for this object.
no setterinherited
items List<AAListItem>
final
onSelected → dynamic Function(int selectedIndex, AAListItem selectedItem)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedIndex int?
getter/setter pair
title String?
Required only when multiple AAListSection are used in the same AAListTemplate.
final
uniqueId String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited