AAMessageTemplateBase class abstract
- Implemented types
- Implementers
Constructors
- AAMessageTemplateBase({required String title, required String message, String? id})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- message ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title ↔ String
-
getter/setter pair
- uniqueId → String
-
no setteroverride
- updateChannelType → FAAChannelTypes
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setMessage(
String message) → Future< void> -
setTitle(
String title) → Future< void> -
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
{String? title, String? message}) → Future< void> - Updates the template content on Android Auto.
-
updateTemplate(
{required String title, required String message}) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited