FlutterAndroidAuto class
An object used to integrate Android Auto navigation and manage user interface elements displayed on the Android Auto screen.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListenerOnConnectionChange(
dynamic onAndroidAutoConnectionChange(ConnectionStatusTypes status)) → void -
closeConnection(
) → void -
forceUpdateRootTemplate(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pauseConnection(
) → void -
removeListenerOnConnectionChange(
) → void -
resumeConnection(
) → void -
toString(
) → String -
A string representation of this object.
inherited
-
updateListTemplateSections(
{required String elementId, required List< AAListSection> sections}) → Future<void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- connectionStatus → String
-
no setter
- rootTemplate → dynamic
-
no setter
- svgRasterSize ↔ int
-
The size used when rasterizing Flutter asset SVGs referenced by image
fields before they are sent to the native side.
getter/setter pair
Static Methods
-
pop(
) → Future< bool> -
popModal(
) → Future< bool> -
popToRoot(
) → Future< bool> -
push(
{required AATemplate template}) → Future< bool> -
setRootTemplate(
{required AATemplate template}) → Future< void> -
showAlert(
{required AAAlertTemplate template}) → Future< void> -
updatePaneTemplate(
{required AAPaneTemplate template}) → Future< bool> -
updateTabBarTemplates(
{required AATabBarTemplate template}) → Future< void>