controllers/all library

Classes

FlutterAndroidAutoController
FlutterAndroidAutoController is a root object used to control and communicate with Android Auto native functions.
FlutterCarPlayController
FlutterCarPlayController is an root object in order to control and communication system with the Apple CarPlay and native functions.