CPAlertAction class
An object that encapsulates an action the user can perform on an action sheet or alert. https://developer.apple.com/documentation/carplay/cpalertaction iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 13.1+
Constructors
- CPAlertAction({required String title, CPAlertActionStyle style = CPAlertActionStyle.normal, required dynamic onPress(), String? id})
- Creates CPAlertAction
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onPress → dynamic Function()
-
The closure that CarPlay invokes after the user taps the action button.
iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 13.1+
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → CPAlertActionStyle
-
The display style for the action button.
Default is CPAlertActionStyle.normal
iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 13.1+
final
- title → String
-
The action button’s title.
iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 13.1+
final
- uniqueId → String
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited