CPAlertTemplate class
A template that displays a modal alert. https://developer.apple.com/documentation/carplay/cpalerttemplate iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 13.1+
- Inheritance
-
- Object
- CPTemplate
- CPAlertTemplate
- Implemented types
Constructors
-
CPAlertTemplate({required List<
String> titleVariants, required List<CPAlertAction> actions, dynamic onPresent(bool completed)?, String? tabTitle, bool showsTabBadge = false, String? systemIcon, String? id}) - Creates CPAlertTemplate
Properties
-
actions
→ List<
CPAlertAction> -
The array of actions available on the alert.
iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 13.1+
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- onPresent → dynamic Function(bool completed)?
-
The closure that CarPlay invokes after the user taps the action button.
Notes:
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showsTabBadge → bool
-
An indicator you use to call attention to the tab.
iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
finalinherited
- systemIcon → String?
-
An image that represents the content of the tab.
Note:
finalinherited
- tabTitle → String?
-
A short title that describes the content of the tab.
iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
finalinherited
-
titleVariants
→ List<
String> -
The array of title variants.
iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 13.1+
final
- uniqueId → String
-
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited