onPresent property
The closure that CarPlay invokes after the user taps the action button. Notes:
- If completed is true, the alert successfully presented. If not, you may want to show an error to the user. iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 13.1+
Implementation
final Function(bool completed)? onPresent;