AutoImageTint.custom constructor
const
AutoImageTint.custom({})
Uses custom RGB byte colors for light and optional dark mode.
Pass color and darkColor as UIColor values with RGB channels from
0 to 255. If darkColor is omitted, color is reused in dark mode.
Implementation
const AutoImageTint.custom({
required UIColor color,
UIColor? darkColor,
bool selectedSafe = true,
}) : this._(
type: AutoImageTintType.custom,
color: color,
darkColor: darkColor,
selectedSafe: selectedSafe,
);