CPGridTemplate constructor
CPGridTemplate({})
Creates CPGridTemplate in order to display a grid of items as buttons. When creating the grid template, provide an array of CPGridButton objects. Each button must contain a title that is shown in the grid template's navigation bar.
Implementation
CPGridTemplate({
required this.title,
required this.buttons,
super.tabTitle,
super.showsTabBadge = false,
super.systemIcon,
String? id,
}) : _elementId = id ?? const Uuid().v4();