models/information/all library
Classes
- CPInformationItem
- A data object that provides content for an information template. https://developer.apple.com/documentation/carplay/cpinformationitem iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
- CPInformationTemplate
- A template object that displays and manages information items and text buttons. https://developer.apple.com/documentation/carplay/cpinformationtemplate iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
Enums
- CPInformationTemplateLayout
- The layout that an information template uses to arrange its items. iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+