CPInformationItem class
A data object that provides content for an information template. https://developer.apple.com/documentation/carplay/cpinformationitem iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
Constructors
- CPInformationItem({String? title, String? detail, String? id})
- Creates CPInformationItem
Properties
- detail → String?
-
The text that the template displays below or beside the item’s title.
iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String?
-
The text that the template displays as the item’s title.
iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
final
- uniqueId → String
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited