CPInformationTemplate class
A template object that displays and manages information items and text buttons. https://developer.apple.com/documentation/carplay/cpinformationtemplate iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
- Inheritance
-
- Object
- CPTemplate
- CPInformationTemplate
Constructors
-
CPInformationTemplate({required String title, required CPInformationTemplateLayout layout, required List<
CPTextButton> actions, required List<CPInformationItem> informationItems, String? tabTitle, bool showsTabBadge = false, String? systemIcon, String? id}) - Creates CPInformationTemplate
Properties
-
actions
→ List<
CPTextButton> -
The actions that the template displays.
iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
informationItems
→ List<
CPInformationItem> -
An array of information items that the template displays.
iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
final
- layout → CPInformationTemplateLayout
-
The layout that the template uses to arrange its items.
iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showsTabBadge → bool
-
An indicator you use to call attention to the tab.
iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
finalinherited
- systemIcon → String?
-
An image that represents the content of the tab.
Note:
finalinherited
- tabTitle → String?
-
A short title that describes the content of the tab.
iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
finalinherited
- title → String
-
The template’s title.
iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
final
- uniqueId → String
-
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited