elements property
The array of elements used to draw visible elements. Can be one of the following types of elements:
- CPListImageRowItemCardElement
- CPListImageRowItemCondensedElement
- CPListImageRowItemRowElement
- CPListImageRowItemGridElement
- CPListImageRowItemImageGridElement iOS 26.0+ | iPadOS 26.0+ | Mac Catalyst 26.0+
Implementation
List<CPListImageRowItemElement>? elements;