models/list/list_image_row_item/all library
Classes
- CPListImageRowItemCardElement
- https://developer.apple.com/documentation/carplay/cplistimagerowitemcardelement iOS 26.0+ | iPadOS 26.0+ | Mac Catalyst 26.0+
- CPListImageRowItemCondensedElement
- https://developer.apple.com/documentation/carplay/cplistimagerowitemcondensedelement iOS 26.0+ | iPadOS 26.0+ | Mac Catalyst 26.0+
- CPListImageRowItemElement
- Abstract superclass for a a row item element object. iOS 26.0+ | iPadOS 26.0+ | Mac Catalyst 26.0+ https://developer.apple.com/documentation/carplay/cplistimagerowitemelement
- CPListImageRowItemGridElement
- https://developer.apple.com/documentation/carplay/cplistimagerowitemgridelement iOS 26.0+ | iPadOS 26.0+ | Mac Catalyst 26.0+
- CPListImageRowItemImageGridElement
- https://developer.apple.com/documentation/carplay/cplistimagerowitemimagegridelement iOS 26.0+ | iPadOS 26.0+ | Mac Catalyst 26.0+
- CPListImageRowItemRowElement
- https://developer.apple.com/documentation/carplay/cplistimagerowitemrowelement iOS 26.0+ | iPadOS 26.0+ | Mac Catalyst 26.0+
Enums
- CPListImageRowItemCondensedElementShape
- Types of shape used to draw a condensed row element. iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 14.0+
- CPListImageRowItemImageGridElementShape
- Types of shape used to draw a condensed row element. iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 14.0+