CPListSection class
A container that groups your list items into sections. https://developer.apple.com/documentation/carplay/cplistsection iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 13.1+
Constructors
-
CPListSection({String? header, bool? sectionIndexEnabled, required List<
CPListTemplateItem> items, String? id}) - Creates CPListSection that contains zero or more list items. You can configure a section to display a header, which CarPlay displays on the trailing edge of the screen.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- header → String?
-
The section’s header text.
iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 13.1+
final
-
items
→ List<
CPListTemplateItem> -
The list of items for the section.
iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 13.1+
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sectionIndexEnabled → bool?
-
The section’s index title.
Defaults to true.
iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 13.1+
final
- uniqueId → String
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited