title property
The title that the navigation bar displays when the template is visible Notes:
- systemIcon must be set in order for the title to be displayed in a tab bar. iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 13.1+
Implementation
final String? title;