CPPointOfInterestTemplate class
A template that displays a map with selectable points of interest. https://developer.apple.com/documentation/carplay/cppointofinteresttemplate iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
- Inheritance
-
- Object
- CPTemplate
- CPPointOfInterestTemplate
Constructors
-
CPPointOfInterestTemplate({required String title, required List<
CPPointOfInterest> poi, String? tabTitle, bool showsTabBadge = false, String? systemIcon, String? id}) - Creates CPPointOfInterestTemplate
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
poi
→ List<
CPPointOfInterest> -
The points of interest the template displays on the map and in the scrollable picker.
iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showsTabBadge → bool
-
An indicator you use to call attention to the tab.
iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
finalinherited
- systemIcon → String?
-
An image that represents the content of the tab.
Note:
finalinherited
- tabTitle → String?
-
A short title that describes the content of the tab.
iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
finalinherited
- title → String
-
The scrollable picker’s title.
iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
final
- uniqueId → String
-
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited