CPTemplate class abstract

https://developer.apple.com/documentation/carplay/cptemplate iOS 12.0+ | iPadOS 12.0+ | Mac Catalyst 13.1+

Implementers

Constructors

CPTemplate({String? tabTitle, bool showsTabBadge = false, String? systemIcon, VoidCallback? onPop})

Properties

hashCode → int
The hash code for this object.
no setterinherited
onPop → VoidCallback?
Called when this template is popped from the navigation stack.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showsTabBadge → bool
An indicator you use to call attention to the tab. iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
final
systemIcon → String?
An image that represents the content of the tab. Note:
final
tabTitle → String?
A short title that describes the content of the tab. iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
final
uniqueId → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited