systemIcon property
An image that represents the content of the tab. Note:
- This property is given to tabImage
- If null, template title will not be display in the tab bar. iOS 14.0+ | iPadOS 14.0+ | Mac Catalyst 14.0+
Implementation
final String? systemIcon;